@@ -118,7 +118,7 @@ def copy_project_skel(project_dir):
     try:
         #Copy the contents of the 'base' folder into the project root
         skelbase=os.path.join(skeldir, 'base')
-        os.system("cp -rp %s %s" % (skelbase, project_dir))
+        os.system("cp -rpv %s/* %s" % (skelbase, project_dir))
 
     except:
         s = "ERROR copying the project skel into %s" % project_dir
