@@ -9,5 +9,7 @@ PACKAGE_NAME_GRAPPELLI = "grappelli_safe"
 # Whether a user's session cookie expires when the Web browser is closed.
 SESSION_EXPIRE_AT_BROWSER_CLOSE = True
 
+# Settings for Django Debug Toolbar
+DEBUG_TOOLBAR_PATCH_SETTINGS=False
 
 
