@@ -14,7 +14,8 @@ if Mezzanine:
 
 # PROJECT SETTINGS (name, path, etc.)
 from backstage.settings.project_settings import *
-#TEMPLATE_DIRS = TEMPLATE_DIRS + PROJECT_TEMPLATE_DIRS
+
+TEMPLATE_DIRS = TEMPLATE_DIRS + PROJECT_TEMPLATE_DIRS
 TEMPLATE_CONTEXT_PROCESSORS = PROJECT_TEMPLATE_CONTEXT_PROCESSORS + TEMPLATE_CONTEXT_PROCESSORS
 
 # DATABASES
@@ -26,9 +27,6 @@ from backstage.settings.app_settings import INSTALLED_APPS
 # STATIC SETTINGS (media_root, staticfiles, etc)
 from backstage.settings.static_settings import *
 
-#TEMPLATE_DIRS
-TEMPLATE_DIRS = TEMPLATE_DIRS + []
-
 # IF MEZZAINE IS INSTALLED:
 if Mezzanine:
     INSTALLED_APPS = INSTALLED_APPS + MEZZANINE_INSTALLED_APPS
@@ -41,6 +39,8 @@ if Mezzanine:
     MIDDLEWARE_CLASSES = MEZZANINE_MIDDLEWARE_CLASSES_PREPEND + \
         MIDDLEWARE_CLASSES + MEZZANINE_MIDDLEWARE_CLASSES_APPEND
 
+    TEMPLATE_DIRS = TEMPLATE_DIRS + MEZZANINE_TEMPLATE_DIRS
+
     #if mezzanine-flexipage is installed
     try:
         from backstage.settings.flexipage_settings import *
